@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.38';
+$VERSION = '0.39';
 
 #--------------------------------------------------------------------------
 
@@ -55,7 +55,7 @@ my $OZ2G  = 0.035274;       # number of ounces (oz) in a gram
 
 =item C<search()>
 
-Creates a query string, then passes the appropriate form fields to the 
+Creates a query string, then passes the appropriate form fields to the
 Amazon (UK) server.
 
 The returned page should be the correct catalog page for that ISBN. If not the
@@ -63,7 +63,7 @@ function returns zero and allows the next driver in the chain to have a go. If
 a valid page is returned, the following fields are returned via the book hash:
 
   isbn          (now returns isbn13)
-  isbn10        
+  isbn10
   isbn13
   ean13         (industry name)
   author
@@ -94,7 +94,7 @@ sub search {
 
     # validate and convert into EAN13 format
     my $ean = $self->convert_to_ean13($isbn);
-    return $self->handler("Invalid ISBN specified [$isbn]")   
+    return $self->handler("Invalid ISBN specified [$isbn]")
         if(!$ean || (length $isbn == 13 && $isbn ne $ean)
                  || (length $isbn == 10 && $isbn ne $self->convert_to_isbn10($ean)));
 
@@ -134,7 +134,7 @@ sub _parse {
     @size                               = $html =~ m!<li><b>\s*Product Dimensions:\s*</b>\s*([\d.]+) x ([\d.]+) x ([\d.]+) (inches)\s*</li>!si unless(@size);
     if(@size) {
         my $type = pop @size;
-        ($data->{depth},$data->{width},$data->{height}) = sort @size;    
+        ($data->{depth},$data->{width},$data->{height}) = sort @size;
         if($type eq 'cm') {
             $data->{$_}  = int($data->{$_} * 10)  for(qw( height width depth ));
         } elsif($type eq 'inches') {
@@ -148,7 +148,8 @@ sub _parse {
     ($data->{isbn10})                   = $html =~ m!<li><b>ISBN-10:</b>\s*(.*?)</li>!si;
     ($data->{isbn13})                   = $html =~ m!<li><b>ISBN-13:</b>\s*(.*?)</li>!si;
     ($data->{content})                  = $html =~ m!<meta name="description" content="([^"]+)"!si;
-    ($data->{description})              = $html =~ m!From the Back Cover</h3>\s*<div class="productDescriptionWrapper"\s*>\s*<P>(.*?)<div!si;  
+    ($data->{description})              = $html =~ m!From the Back Cover</h3>\s*<div class="productDescriptionWrapper"\s*>\s*<P>(.*?)<div!si;
+    ($data->{description})              = $html =~ m!<div id="bookDescription_feature_div"[^>]*>.*?<noscript>(.*?)</noscript!si unless($data->{description});
 
     $data->{weight} = int($data->{weight} / $OZ2G)  if($data->{weight});
 
@@ -166,9 +167,18 @@ sub _parse {
         $data->{image_link} = $order[-1]    if(@order);
 
 #use Data::Dumper;
+#print STDERR "\n# code=[".Dumper($code)."]\n";
+    } else {
+        my ($code) = $html =~ /'imageGalleryData'\s*:\s*([^;]+);/si;
+        if($code) {
+            ($data->{thumb_link}) = $code =~ /"thumbUrl":\s*"([^+]+)"/;
+            ($data->{image_link}) = $code =~ /"mainUrl":\s*"([^+]+)"/;
+        }
+#use Data::Dumper;
 #print STDERR "\n# code=[".Dumper($code)."]\n";
     }
 
+
 #    {\"initial\":[{\"large\":\"http://ecx.images-amazon.com/images/I/31cLTIXHKgL.jpg\",\"landing\":[\"http://ecx.images-amazon.com/images/I/31cLTIXHKgL._SY300_.jpg\"],\"thumb\":\"http://ecx.images-amazon.com/images/I/31cLTIXHKgL._SS40_.jpg\",\"main\":[\"http://ecx.images-amazon.com/images/I/31cLTIXHKgL._SX342_.jpg\",\"http://ecx.images-amazon.com/images/I/31cLTIXHKgL._SX385_.jpg\"]}]};
 
     if($data->{content}) {
